@@ -9,9 +9,9 @@ require v5.16.0;
 use warnings FATAL => qw(all);
 use strict;
 use Carp;
-use Data::Table::Text qw(:all);
+use Data::Table::Text 2017.114 qw(:all);
 use Data::Dump qw(dump);
-our $VERSION = 2017.115;
+our $VERSION = 2017.116;
 
 saveToS3('BinaryHeapArray') if 0;
 
